@@ -152,7 +152,12 @@ class ScopeProviderTest(UnitTest):
                 self.assertEqual(scopes[alias], scope_of_module)
 
         for idx, in_scopes in enumerate(
-            [["foo", "foo.bar"], ["fizzbuzz"], ["a", "a.b", "a.b.c"], ["g"],]
+            [
+                ["foo", "foo.bar"],
+                ["fizzbuzz"],
+                ["a", "a.b", "a.b.c"],
+                ["g"],
+            ]
         ):
             for in_scope in in_scopes:
                 self.assertEqual(
@@ -1010,6 +1015,59 @@ class ScopeProviderTest(UnitTest):
 
         self.assertEqual(len(set(scopes.values())), 3)
 
+    def test_annotation_access(self) -> None:
+        m, scopes = get_scope_metadata_provider(
+            """
+                from typing import Literal, TypeVar
+                from a import A, B, C, D, E, F
+                def x(a: A):
+                    pass
+                def y(b: "B"):
+                    pass
+                def z(c: Literal["C"]):
+                    pass
+                DType = TypeVar("DType", bound=D)
+                EType = TypeVar("EType", bound="E")
+                FType = TypeVar("F")
+            """
+        )
+        imp = ensure_type(
+            ensure_type(m.body[1], cst.SimpleStatementLine).body[0], cst.ImportFrom
+        )
+        scope = scopes[imp]
+
+        assignment = list(scope["A"])[0]
+        self.assertIsInstance(assignment, Assignment)
+        self.assertEqual(len(assignment.references), 1)
+        references = list(assignment.references)
+        self.assertTrue(references[0].is_annotation)
+
+        assignment = list(scope["B"])[0]
+        self.assertIsInstance(assignment, Assignment)
+        self.assertEqual(len(assignment.references), 1)
+        references = list(assignment.references)
+        self.assertTrue(references[0].is_annotation)
+
+        assignment = list(scope["C"])[0]
+        self.assertIsInstance(assignment, Assignment)
+        self.assertEqual(len(assignment.references), 0)
+
+        assignment = list(scope["D"])[0]
+        self.assertIsInstance(assignment, Assignment)
+        self.assertEqual(len(assignment.references), 1)
+        references = list(assignment.references)
+        self.assertTrue(references[0].is_annotation)
+
+        assignment = list(scope["E"])[0]
+        self.assertIsInstance(assignment, Assignment)
+        self.assertEqual(len(assignment.references), 1)
+        references = list(assignment.references)
+        self.assertTrue(references[0].is_annotation)
+
+        assignment = list(scope["F"])[0]
+        self.assertIsInstance(assignment, Assignment)
+        self.assertEqual(len(assignment.references), 0)
+
     def test_node_of_scopes(self) -> None:
         m, scopes = get_scope_metadata_provider(
             """
